package com.winhc.repal.config;

import com.alibaba.fastjson.JSON;
import com.module.login.usersession.UserBean;
import com.winhc.common.enums.CodeMsg;
import com.winhc.common.exception.CommonException;
import com.winhc.repal.model.bo.UserContextBO;
import com.winhc.repal.util.UserContextUtil;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Objects;

/**
 * @Description: LoginInterceptor
 * @Author: xda
 * @Date: 2022/3/31 17:07
 */
public class UserContextInterceptor implements HandlerInterceptor {

    public static final Logger LOGGER = LoggerFactory.getLogger(UserContextInterceptor.class);

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
        // 保存用户信息到threadLocal
        String userInfo = request.getHeader("userInfo");
        if (StringUtils.isEmpty(userInfo)) {
            throw new CommonException(CodeMsg.UNAUTHORIZED);
        }
        UserBean userBean = JSON.parseObject(userInfo, UserBean.class);
        if (Objects.isNull(userBean)) {
            throw new CommonException(CodeMsg.UNAUTHORIZED);
        }
        LOGGER.info("currentUser: [{}]", userInfo);
        UserContextUtil.saveUser(UserContextBO.builderBO(userBean.getUserId(), request.getHeader("appVersion"), request.getHeader("appPackage")));
        return true;
    }


    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) {
        UserContextUtil.removeUser();
    }
}
