package com.winhc.repal.controller;

import com.winhc.common.base.BeanResponse;
import com.winhc.common.enums.CodeMsg;
import com.winhc.common.model.base.VOPage;
import com.winhc.repal.common.BaseController;
import com.winhc.repal.enums.Dict;
import com.winhc.repal.model.dto.RepalCustomerDTO;
import com.winhc.repal.model.dto.RepalCustomerQueryDTO;
import com.winhc.repal.model.dto.RepalCustomerUpdateDTO;
import com.winhc.repal.model.vo.RepalCustomerDetailVO;
import com.winhc.repal.model.vo.RepalCustomerInfoVO;
import com.winhc.repal.service.RepalCustomerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author Aaron
 * @date 2022/4/19 13:08
 * @description
 */
@Api(tags = "回款宝 客户/供应 商管理")
@RestController
@RequestMapping(value = "/repalCustomer")
public class RepalCustomerController extends BaseController {
    @Autowired
    private RepalCustomerService repalCustomerService;

    @ApiOperation("分页查询客户")
    @GetMapping(value = "/cust/page")
    public BeanResponse<VOPage<RepalCustomerInfoVO>> getRepalCustPage(RepalCustomerQueryDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.find(dto.setCustType(Dict.custTypeEnum.客户.getCode()),getUser()));
    }

    @ApiOperation("添加客户")
    @PostMapping("/cust")
    public BeanResponse<RepalCustomerDetailVO> addCustomer(@RequestBody RepalCustomerDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.addCustomer(dto.setCustType(Dict.custTypeEnum.客户.getCode()),getUser()));
    }

    @ApiOperation("修改客户")
    @PostMapping("/cust/modify")
    public BeanResponse<RepalCustomerDetailVO> modifyCustomer(@RequestBody RepalCustomerUpdateDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.updateCustomer(dto.setCustType(Dict.custTypeEnum.客户.getCode()),getUser()));
    }

    @ApiOperation("客户详情")
    @GetMapping(value = "/cust/{custId}")
    public BeanResponse<RepalCustomerDetailVO> getRepalCustomerDetail(@PathVariable("custId")Long custId){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.getDetailById(custId,getUser(),Dict.custTypeEnum.客户.getCode()));
    }

    @ApiOperation("分页查询供应商")
    @GetMapping(value = "/supply/page")
    public BeanResponse<VOPage<RepalCustomerInfoVO>> getRepalSupplyPage(RepalCustomerQueryDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.find(dto.setCustType(Dict.custTypeEnum.供应商.getCode()),getUser()));
    }

    @ApiOperation("添加供应商")
    @PostMapping("/supply")
    public BeanResponse<RepalCustomerDetailVO> addSupply(@RequestBody RepalCustomerDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.addCustomer(dto.setCustType(Dict.custTypeEnum.客户.getCode()),getUser()));
    }

    @ApiOperation("修改供应商")
    @PostMapping("/supply/modify")
    public BeanResponse<RepalCustomerDetailVO> modifySupply(@RequestBody RepalCustomerUpdateDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.updateCustomer(dto.setCustType(Dict.custTypeEnum.供应商.getCode()),getUser()));
    }

    @ApiOperation("供应商详情")
    @GetMapping(value = "/supply/{custId}")
    public BeanResponse<RepalCustomerDetailVO> getRepalSupplyDetail(@PathVariable("custId")Long custId){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.getDetailById(custId,getUser(),Dict.custTypeEnum.供应商.getCode()));
    }

    @ApiOperation("删除客户/供应商")
    @DeleteMapping("/{custId}")
    public BeanResponse<Boolean> deleteCustomer(@PathVariable("custId")Long custId){
        return BeanResponse.success(CodeMsg.SUCCESS,repalCustomerService.deleteCustomer(custId,getUser()));
    }
}
