package com.winhc.repal.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.winhc.common.enums.CodeMsg;
import com.winhc.common.exception.CommonException;
import com.winhc.repal.entity.RepalBook;
import com.winhc.repal.enums.DeletedStatusEnum;
import com.winhc.repal.enums.PermissionEnum;
import com.winhc.repal.model.dto.DeleteRepalBookDTO;
import com.winhc.repal.model.vo.RepalBookHomeVO;
import com.winhc.repal.model.vo.RepalBookInfoVO;
import com.winhc.repal.repository.RepalBookMapper;
import com.winhc.repal.service.RepalBillService;
import com.winhc.repal.service.RepalBookService;
import com.winhc.repal.service.RepalGroupMemberService;
import com.winhc.repal.service.RepalRolePermissionService;
import com.winhc.repal.util.UserContextUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * @description RepalBook 接口实现类
 * @author Generator
 * @date 2022-04-08
 */
@Service
public class RepalBookServiceImpl extends ServiceImpl<RepalBookMapper, RepalBook> implements RepalBookService {

    @Autowired
    private RepalBookMapper repalBookMapper;

    @Autowired
    private RepalBillService repalBillService;

    @Autowired
    private RepalRolePermissionService repalRolePermissionService;

    @Autowired
    private RepalGroupMemberService repalGroupMemberService;

//    @Override
//    public RepalBookHomeVO getRepalHomeDetail(Long repalGroupId) {
//        RepalBookHomeVO vo = new RepalBookHomeVO();
//        return vo;
//    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean deleteRepalBook(DeleteRepalBookDTO dto) {
        long groupId = repalGroupMemberService.getUserGroupId(UserContextUtil.getUser().getUserId());
        int count = this.count(Wrappers.lambdaQuery(RepalBook.class)
                .eq(RepalBook::getRepalGroupId, groupId)
                .eq(RepalBook::getDeleted, DeletedStatusEnum.NORMAL.getCode()));
        if (count < 2) {
            throw new CommonException(CodeMsg.FAILED, "必须保留一个账本哦～");
        }
        if (!this.update(Wrappers.lambdaUpdate(RepalBook.class)
                .eq(RepalBook::getRepalGroupId, groupId)
                .set(RepalBook::getDeleted, DeletedStatusEnum.NORMAL.getCode()))) {
            throw new CommonException(CodeMsg.FAILED, "参数错误");
        }
        // 账款和账款关联责任人也删掉
        repalBillService.deleteRepalBillByBookId(dto.getRepalBookId());
        return true;
    }

    @Override
    public List<RepalBookInfoVO> getRepalBookInfoList() {
        Set<String> codeSet = repalRolePermissionService.getUserPermissionCodeSet(UserContextUtil.getUser().getUserId());
        // todo
        //boolean receivableFlag = codeSet.contains(PermissionEnum.QUERY_ALL_RECEIVABLE.getCode());
        boolean receivableFlag = true;
        //boolean receiptFlag = codeSet.contains(PermissionEnum.QUERY_ALL_RECEIPT.getCode());
        boolean receiptFlag = true;
        return repalBookMapper.getRepalBookInfoList(UserContextUtil.getUser().getUserId(), repalGroupMemberService.getUserGroupId(UserContextUtil.getUser().getUserId()), receivableFlag, receiptFlag);
    }
}
